/*
	jQuery Hooks for WordPress

	Examples:

	// Add three different test actions
	$.wp.addAction( 'test', function() { alert('Foo!'); } );
	$.wp.addAction( 'test', function() { alert('Bar!'); } );
	$.wp.addAction( 'test', function() { alert('Baz!'); } );

	// Remove the first one
	$.wp.removeAction( 'test', 'test_1' );

	// Do the remaining test actions
	$.wp.doAction( 'test' );


	// Add a filter somewhere
	$.wp.addFilter('filterOptions',function(options) {
		// Do stuff here to modify variable options
		return options;
	} );

	// Use the filter here
	options = $.wp.applyFilters('filterOptions',options);

 */
jQuery(document).ready(function($) {
	$.wp = {
		/**
		 * Implement a WordPress-link Hook System for Javascript
		 * TODO: Change 'tag' to 'args', allow number (priority), string (tag), object (priority+tag)
		 */
		hooks: { action: {}, filter: {} },
		addAction: function( action, callable, tag ) {
			jQuery.wp.addHook( 'action', action, callable, tag );
		},
		addFilter: function( action, callable, tag ) {
			jQuery.wp.addHook( 'filter', action, callable, tag );
		},
		doAction: function( action, args ) {
			jQuery.wp.doHook( 'action', action, null, args );
		},
		applyFilters: function( action, value, args ) {
			return jQuery.wp.doHook( 'filter', action, value, args );
		},
		removeAction: function( action, tag ) {
			jQuery.wp.removeHook( 'action', action, tag );
		},
		removeFilter: function( action, tag ) {
			jQuery.wp.removeHook( 'filter', action, tag );
		},
		addHook: function( hookType, action, callable, tag ) {
			if ( undefined == jQuery.wp.hooks[hookType][action] ) {
				jQuery.wp.hooks[hookType][action] = [];
			}
			var hooks = jQuery.wp.hooks[hookType][action];
			if ( undefined == tag ) {
				tag = action + '_' + hooks.length;
			}
			jQuery.wp.hooks[hookType][action].push( { tag:tag, callable:callable } );
		},
		doHook: function( hookType, action, value, args ) {
			if ( undefined != jQuery.wp.hooks[hookType][action] ) {
				var hooks = jQuery.wp.hooks[hookType][action];
				for( var i=0; i<hooks.length; i++) {
					if ( 'action'==hookType ) {
						hooks[i].callable(args);
					} else {
						value = hooks[i].callable(value, args);
					}
				}
			}
			if ( 'filter'==hookType ) {
				return value;
			}
		},
		removeHook: function( hookType, action, tag ) {
			if ( undefined != jQuery.wp.hooks[hookType][action] ) {
				var hooks = jQuery.wp.hooks[hookType][action];
				for( var i=hooks.length-1; i>=0; i--) {
					if (undefined==tag||tag==hooks[i].tag)
						hooks.splice(i,1);
					}
				}
			}
	}
});




